=========
Changelog
=========

Version 0.0.4
===========

- Added support for searching in
    * Google
    * Wikipedia
    * Wirecutter
    * Amazon
    * Creative Commons images
    * IMDb
    * Swiggy


Version 0.0.1
===========

- Added support for search in DuckDuckGo
